/* upsd.h - support structures and other minor details

   Copyright (C) 1999  Russell Kroll <rkroll@exploits.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/

/*
 * Much of the content from here was also useful to the
 * drivers, so has been moved into include/shared-tables.h
 * instead of being within the daemon specific include file
 *
 */

#ifndef UPSD_H_SEEN
#define UPSD_H_SEEN

#include "common.h"
#include "shared.h"

#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>

#ifdef HAVE_MMAP
#include <sys/mman.h>
#endif

#include "timehead.h"

#include <sys/file.h>

#include "parseconf.h"

/* ACL structure */
typedef struct {
        char    *name;
        unsigned int    addr;
        unsigned int    mask;
        void    *next;
}       acltype;

/* ACCESS structure */
typedef struct {
	int	action;
	int	level;
	char	*aclname;
	char	*password;
	void	*next;
}	acctype;

/* structure for the linked list of each UPS that we track */
typedef struct {
	char	*name;
	char	*fn;

	int			sock_fd;
	int			stale;
	time_t			last_heard;
	time_t			last_ping;
	time_t			last_connfail;
	PCONF_CTX		sock_ctx;
	struct	st_tree_t	*inforoot;
	struct	cmdlist_t	*cmdlist;

	int	numlogins;
	int	fsd;		/* forced shutdown in effect? */

	int	retain;
	void	*next;
}	upstype;

/* prototypes from upsd.c */

int checkacl(const char *aclname, const struct sockaddr_in *addr);
void addups(char *fn, char *name);
void addacl(char *aclname, char *ipblock);
void addaccess(const char *action, char *level, char *aclname, char *password);
upstype *findups(const char *upsname);
void redefine_ups(char *fn, char *name);
void kick_login_clients(char *upsname);
int sendback(const struct sockaddr_in *dest, const char *fmt, ...);

/* prototypes from user.c: user handling functions */

void user_load(void);
int user_checkinstcmd(struct sockaddr_in *ip, char *username, char *password,
                      int cmd);
int user_checkaction(struct sockaddr_in *ip, const char *username, 
	const char *password, const char *action);

extern int upslog_flags;

/* map commands onto signals */

#define SIGCMD_STOP	SIGTERM
#define SIGCMD_RELOAD	SIGHUP

#endif	/* UPSD_H_SEEN */
